/****************************************************************************
** Meta object code from reading C++ file 'kimagemapeditor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kimagemapeditor-26.04.3/kimagemapeditor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kimagemapeditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15KImageMapEditorE_t {};
} // unnamed namespace

template <> constexpr inline auto KImageMapEditor::qt_create_metaobjectdata<qt_meta_tag_ZN15KImageMapEditorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KImageMapEditor",
        "openURL",
        "",
        "QUrl",
        "url",
        "slotChangeStatusCoords",
        "x",
        "y",
        "slotUpdateSelectionCoords",
        "QRect",
        "slotAreaChanged",
        "Area*",
        "slotShowMainPopupMenu",
        "QPoint",
        "slotShowMapPopupMenu",
        "slotShowImagePopupMenu",
        "slotConfigChanged",
        "setPicture",
        "setMap",
        "setMapName",
        "s",
        "openFile",
        "saveFile",
        "fileOpen",
        "fileSaveAs",
        "fileSave",
        "fileClose",
        "slotShowPopupMenu",
        "slotShowPreferences",
        "slotHighlightAreas",
        "b",
        "slotShowAltTag",
        "slotSelectionChanged",
        "showTagEditor",
        "QTreeWidgetItem*",
        "item",
        "slotZoom",
        "slotZoomIn",
        "slotZoomOut",
        "slotCut",
        "slotCopy",
        "slotPaste",
        "slotDelete",
        "slotDrawArrow",
        "slotDrawCircle",
        "slotDrawRectangle",
        "slotDrawPolygon",
        "slotDrawFreehand",
        "slotDrawAddPoint",
        "slotDrawRemovePoint",
        "mapDefaultArea",
        "mapNew",
        "mapDelete",
        "mapEditName",
        "mapShowHTML",
        "mapPreview",
        "slotBackOne",
        "slotForwardOne",
        "slotToBack",
        "slotToFront",
        "slotMoveUp",
        "slotMoveDown",
        "slotMoveLeft",
        "slotMoveRight",
        "slotIncreaseHeight",
        "slotDecreaseHeight",
        "slotIncreaseWidth",
        "slotDecreaseWidth",
        "slotCancelDrawing",
        "imageAdd",
        "imageRemove",
        "imageUsemap"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'openURL'
        QtMocHelpers::SlotData<bool(const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotChangeStatusCoords'
        QtMocHelpers::SlotData<void(int, int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::Int, 7 },
        }}),
        // Slot 'slotUpdateSelectionCoords'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateSelectionCoords'
        QtMocHelpers::SlotData<void(const QRect &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Slot 'slotAreaChanged'
        QtMocHelpers::SlotData<void(Area *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Slot 'slotShowMainPopupMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'slotShowMapPopupMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'slotShowImagePopupMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'slotConfigChanged'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setPicture'
        QtMocHelpers::SlotData<void(const QUrl &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'setMap'
        QtMocHelpers::SlotData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'setMapName'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'openFile'
        QtMocHelpers::SlotData<bool()>(21, 2, QMC::AccessProtected, QMetaType::Bool),
        // Slot 'saveFile'
        QtMocHelpers::SlotData<bool()>(22, 2, QMC::AccessProtected, QMetaType::Bool),
        // Slot 'fileOpen'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'fileSaveAs'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'fileSave'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'fileClose'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotShowPopupMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(27, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'slotShowPreferences'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotHighlightAreas'
        QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'slotShowAltTag'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'slotSelectionChanged'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'showTagEditor'
        QtMocHelpers::SlotData<int(QTreeWidgetItem *)>(33, 2, QMC::AccessProtected, QMetaType::Int, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Slot 'showTagEditor'
        QtMocHelpers::SlotData<int()>(33, 2, QMC::AccessProtected, QMetaType::Int),
        // Slot 'slotZoom'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotZoomIn'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotZoomOut'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotCut'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotCopy'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotPaste'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDelete'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDrawArrow'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDrawCircle'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDrawRectangle'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDrawPolygon'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDrawFreehand'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDrawAddPoint'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDrawRemovePoint'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'mapDefaultArea'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'mapNew'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'mapDelete'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'mapEditName'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'mapShowHTML'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'mapPreview'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotBackOne'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotForwardOne'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotToBack'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotToFront'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotMoveUp'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotMoveDown'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotMoveLeft'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotMoveRight'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotIncreaseHeight'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDecreaseHeight'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotIncreaseWidth'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDecreaseWidth'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotCancelDrawing'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'imageAdd'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'imageRemove'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'imageUsemap'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KImageMapEditor, qt_meta_tag_ZN15KImageMapEditorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KImageMapEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::ReadWritePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KImageMapEditorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KImageMapEditorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KImageMapEditorE_t>.metaTypes,
    nullptr
} };

void KImageMapEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KImageMapEditor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->openURL((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->slotChangeStatusCoords((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->slotUpdateSelectionCoords(); break;
        case 3: _t->slotUpdateSelectionCoords((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 4: _t->slotAreaChanged((*reinterpret_cast<std::add_pointer_t<Area*>>(_a[1]))); break;
        case 5: _t->slotShowMainPopupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 6: _t->slotShowMapPopupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 7: _t->slotShowImagePopupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 8: _t->slotConfigChanged(); break;
        case 9: _t->setPicture((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 10: _t->setMap((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->setMapName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: { bool _r = _t->openFile();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->saveFile();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->fileOpen(); break;
        case 15: _t->fileSaveAs(); break;
        case 16: _t->fileSave(); break;
        case 17: _t->fileClose(); break;
        case 18: _t->slotShowPopupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 19: _t->slotShowPreferences(); break;
        case 20: _t->slotHighlightAreas((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->slotShowAltTag((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->slotSelectionChanged(); break;
        case 23: { int _r = _t->showTagEditor((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 24: { int _r = _t->showTagEditor();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->slotZoom(); break;
        case 26: _t->slotZoomIn(); break;
        case 27: _t->slotZoomOut(); break;
        case 28: _t->slotCut(); break;
        case 29: _t->slotCopy(); break;
        case 30: _t->slotPaste(); break;
        case 31: _t->slotDelete(); break;
        case 32: _t->slotDrawArrow(); break;
        case 33: _t->slotDrawCircle(); break;
        case 34: _t->slotDrawRectangle(); break;
        case 35: _t->slotDrawPolygon(); break;
        case 36: _t->slotDrawFreehand(); break;
        case 37: _t->slotDrawAddPoint(); break;
        case 38: _t->slotDrawRemovePoint(); break;
        case 39: _t->mapDefaultArea(); break;
        case 40: _t->mapNew(); break;
        case 41: _t->mapDelete(); break;
        case 42: _t->mapEditName(); break;
        case 43: _t->mapShowHTML(); break;
        case 44: _t->mapPreview(); break;
        case 45: _t->slotBackOne(); break;
        case 46: _t->slotForwardOne(); break;
        case 47: _t->slotToBack(); break;
        case 48: _t->slotToFront(); break;
        case 49: _t->slotMoveUp(); break;
        case 50: _t->slotMoveDown(); break;
        case 51: _t->slotMoveLeft(); break;
        case 52: _t->slotMoveRight(); break;
        case 53: _t->slotIncreaseHeight(); break;
        case 54: _t->slotDecreaseHeight(); break;
        case 55: _t->slotIncreaseWidth(); break;
        case 56: _t->slotDecreaseWidth(); break;
        case 57: _t->slotCancelDrawing(); break;
        case 58: _t->imageAdd(); break;
        case 59: _t->imageRemove(); break;
        case 60: _t->imageUsemap(); break;
        default: ;
        }
    }
}

const QMetaObject *KImageMapEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KImageMapEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KImageMapEditorE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KImageMapEditorInterface"))
        return static_cast< KImageMapEditorInterface*>(this);
    if (!strcmp(_clname, "org.kde.KImageMapEditorInterface"))
        return static_cast< KImageMapEditorInterface*>(this);
    return KParts::ReadWritePart::qt_metacast(_clname);
}

int KImageMapEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::ReadWritePart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 61)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 61;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 61)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 61;
    }
    return _id;
}
QT_WARNING_POP
